@@ -43,18 +43,27 @@ def base_format(  # noqa: WPS231
     """
     markdown = MarkdownConverter(md)
     extra = options.get("extra", {})
+
     try:
         output = run(code, **extra)
     except RuntimeError as error:
         logger.warning(f"Execution of {language} code block exited with non-zero status")
         return markdown.convert(str(error))
-    stash = {}
+
     if html:
-        placeholder = str(uuid4())
-        stash[placeholder] = output
-        output = placeholder
-    elif result:
-        output = code_block(result, output)
+        if source:
+            placeholder = str(uuid4())
+            wrapped_output = add_source(
+                source=code, location=source, output=placeholder, language=language, tabs=tabs, **extra
+            )
+            return markdown.convert(wrapped_output, stash={placeholder: output})
+        return Markup(output)
+
+    wrapped_output = output
+    if result:
+        wrapped_output = code_block(result, output)
     if source:
-        output = add_source(source=code, location=source, output=output, language=language, tabs=tabs, **extra)
-    return markdown.convert(output, stash=stash)
+        wrapped_output = add_source(
+            source=code, location=source, output=wrapped_output, language=language, tabs=tabs, **extra
+        )
+    return markdown.convert(wrapped_output)
